@@ -152,6 +152,9 @@ ListOutpostsInputRequestTypeDef = TypedDict(
     {
         "NextToken": str,
         "MaxResults": int,
+        "LifeCycleStatusFilter": List[str],
+        "AvailabilityZoneFilter": List[str],
+        "AvailabilityZoneIdFilter": List[str],
     },
     total=False,
 )
